@@ -208,5 +208,5 @@ def write_mo(fileobj: SupportsWrite[bytes], catalog: Catalog, use_fuzzy: bool =
                               len(messages),              # number of entries
                               7 * 4,                      # start of key index
                               7 * 4 + len(messages) * 8,  # start of value index
-                              0, 0                        # size and offset of hash table
+                              0, 0,                       # size and offset of hash table
                               ) + array.array.tobytes(array.array("i", offsets)) + ids + strs)
